==> zio-aws-elasticloadbalancingv2_2.12-5.17.121.3-sources.jar: zio/aws/elasticloadbalancingv2/model/TargetGroup.scala <==
package zio.aws.elasticloadbalancingv2.model
import java.lang.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.elasticloadbalancingv2.model.primitives.{
  VpcId,
  LoadBalancerArn,
  HealthCheckThresholdCount,
  Port,
  HealthCheckTimeoutSeconds,
  ProtocolVersion,
  HealthCheckEnabled,
  HealthCheckIntervalSeconds,
  TargetGroupArn,
  Path,
  TargetGroupName,
  HealthCheckPort
}
import scala.jdk.CollectionConverters._
final case class TargetGroup(
    targetGroupArn: Option[TargetGroupArn] = None,
    targetGroupName: Option[TargetGroupName] = None,
    protocol: Option[zio.aws.elasticloadbalancingv2.model.ProtocolEnum] = None,
    port: Option[Port] = None,
    vpcId: Option[VpcId] = None,
    healthCheckProtocol: Option[
      zio.aws.elasticloadbalancingv2.model.ProtocolEnum
    ] = None,
    healthCheckPort: Option[HealthCheckPort] = None,
    healthCheckEnabled: Option[HealthCheckEnabled] = None,
    healthCheckIntervalSeconds: Option[HealthCheckIntervalSeconds] = None,
    healthCheckTimeoutSeconds: Option[HealthCheckTimeoutSeconds] = None,
    healthyThresholdCount: Option[HealthCheckThresholdCount] = None,
    unhealthyThresholdCount: Option[HealthCheckThresholdCount] = None,
    healthCheckPath: Option[Path] = None,
    matcher: Option[zio.aws.elasticloadbalancingv2.model.Matcher] = None,
    loadBalancerArns: Option[Iterable[LoadBalancerArn]] = None,
    targetType: Option[zio.aws.elasticloadbalancingv2.model.TargetTypeEnum] =
      None,
    protocolVersion: Option[ProtocolVersion] = None,
    ipAddressType: Option[
      zio.aws.elasticloadbalancingv2.model.TargetGroupIpAddressTypeEnum
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticloadbalancingv2.model.TargetGroup = {
    import TargetGroup.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticloadbalancingv2.model.TargetGroup
      .builder()
      .optionallyWith(
        targetGroupArn.map(value =>
          TargetGroupArn.unwrap(value): java.lang.String
        )
      )(_.targetGroupArn)
      .optionallyWith(
        targetGroupName.map(value =>
          TargetGroupName.unwrap(value): java.lang.String
        )
      )(_.targetGroupName)
      .optionallyWith(protocol.map(value => value.unwrap))(_.protocol)
      .optionallyWith(port.map(value => Port.unwrap(value): Integer))(_.port)
      .optionallyWith(
        vpcId.map(value => VpcId.unwrap(value): java.lang.String)
      )(_.vpcId)
      .optionallyWith(healthCheckProtocol.map(value => value.unwrap))(
        _.healthCheckProtocol
      )
      .optionallyWith(
        healthCheckPort.map(value =>
          HealthCheckPort.unwrap(value): java.lang.String
        )
      )(_.healthCheckPort)
      .optionallyWith(
        healthCheckEnabled.map(value =>
          HealthCheckEnabled.unwrap(value): java.lang.Boolean
        )
      )(_.healthCheckEnabled)
      .optionallyWith(
        healthCheckIntervalSeconds.map(value =>
          HealthCheckIntervalSeconds.unwrap(value): Integer
        )
      )(_.healthCheckIntervalSeconds)
      .optionallyWith(
        healthCheckTimeoutSeconds.map(value =>
          HealthCheckTimeoutSeconds.unwrap(value): Integer
        )
      )(_.healthCheckTimeoutSeconds)
      .optionallyWith(
        healthyThresholdCount.map(value =>
          HealthCheckThresholdCount.unwrap(value): Integer
        )
      )(_.healthyThresholdCount)
      .optionallyWith(
        unhealthyThresholdCount.map(value =>
          HealthCheckThresholdCount.unwrap(value): Integer
        )
      )(_.unhealthyThresholdCount)
      .optionallyWith(
        healthCheckPath.map(value => Path.unwrap(value): java.lang.String)
      )(_.healthCheckPath)
      .optionallyWith(matcher.map(value => value.buildAwsValue()))(_.matcher)
      .optionallyWith(
        loadBalancerArns.map(value =>
          value.map { item =>
            LoadBalancerArn.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.loadBalancerArns)
      .optionallyWith(targetType.map(value => value.unwrap))(_.targetType)
      .optionallyWith(
        protocolVersion.map(value =>
          ProtocolVersion.unwrap(value): java.lang.String
        )
      )(_.protocolVersion)
      .optionallyWith(ipAddressType.map(value => value.unwrap))(_.ipAddressType)
      .build()
  }
  def asReadOnly: zio.aws.elasticloadbalancingv2.model.TargetGroup.ReadOnly =
    zio.aws.elasticloadbalancingv2.model.TargetGroup.wrap(buildAwsValue())
}
object TargetGroup {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticloadbalancingv2.model.TargetGroup
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticloadbalancingv2.model.TargetGroup =
      zio.aws.elasticloadbalancingv2.model.TargetGroup(
        targetGroupArn.map(value => value),
        targetGroupName.map(value => value),
        protocol.map(value => value),
        port.map(value => value),
        vpcId.map(value => value),
        healthCheckProtocol.map(value => value),
        healthCheckPort.map(value => value),
        healthCheckEnabled.map(value => value),
        healthCheckIntervalSeconds.map(value => value),
        healthCheckTimeoutSeconds.map(value => value),
        healthyThresholdCount.map(value => value),
        unhealthyThresholdCount.map(value => value),
        healthCheckPath.map(value => value),
        matcher.map(value => value.asEditable),
        loadBalancerArns.map(value => value),
        targetType.map(value => value),
        protocolVersion.map(value => value),
        ipAddressType.map(value => value)
      )
    def targetGroupArn: Option[TargetGroupArn]
    def targetGroupName: Option[TargetGroupName]
    def protocol: Option[zio.aws.elasticloadbalancingv2.model.ProtocolEnum]
    def port: Option[Port]
    def vpcId: Option[VpcId]
    def healthCheckProtocol
        : Option[zio.aws.elasticloadbalancingv2.model.ProtocolEnum]
    def healthCheckPort: Option[HealthCheckPort]
    def healthCheckEnabled: Option[HealthCheckEnabled]
    def healthCheckIntervalSeconds: Option[HealthCheckIntervalSeconds]
    def healthCheckTimeoutSeconds: Option[HealthCheckTimeoutSeconds]
    def healthyThresholdCount: Option[HealthCheckThresholdCount]
    def unhealthyThresholdCount: Option[HealthCheckThresholdCount]
    def healthCheckPath: Option[Path]
    def matcher: Option[zio.aws.elasticloadbalancingv2.model.Matcher.ReadOnly]
    def loadBalancerArns: Option[List[LoadBalancerArn]]
    def targetType: Option[zio.aws.elasticloadbalancingv2.model.TargetTypeEnum]
    def protocolVersion: Option[ProtocolVersion]
    def ipAddressType: Option[
      zio.aws.elasticloadbalancingv2.model.TargetGroupIpAddressTypeEnum
    ]
    def getTargetGroupArn: ZIO[Any, AwsError, TargetGroupArn] =
      AwsError.unwrapOptionField("targetGroupArn", targetGroupArn)
    def getTargetGroupName: ZIO[Any, AwsError, TargetGroupName] =
      AwsError.unwrapOptionField("targetGroupName", targetGroupName)
    def getProtocol: ZIO[
      Any,
      AwsError,
      zio.aws.elasticloadbalancingv2.model.ProtocolEnum
    ] = AwsError.unwrapOptionField("protocol", protocol)
    def getPort: ZIO[Any, AwsError, Port] =
      AwsError.unwrapOptionField("port", port)
    def getVpcId: ZIO[Any, AwsError, VpcId] =
      AwsError.unwrapOptionField("vpcId", vpcId)
    def getHealthCheckProtocol: ZIO[
      Any,
      AwsError,
      zio.aws.elasticloadbalancingv2.model.ProtocolEnum
    ] = AwsError.unwrapOptionField("healthCheckProtocol", healthCheckProtocol)
    def getHealthCheckPort: ZIO[Any, AwsError, HealthCheckPort] =
      AwsError.unwrapOptionField("healthCheckPort", healthCheckPort)
    def getHealthCheckEnabled: ZIO[Any, AwsError, HealthCheckEnabled] =
      AwsError.unwrapOptionField("healthCheckEnabled", healthCheckEnabled)
    def getHealthCheckIntervalSeconds
        : ZIO[Any, AwsError, HealthCheckIntervalSeconds] =
      AwsError.unwrapOptionField(
        "healthCheckIntervalSeconds",
        healthCheckIntervalSeconds
      )
    def getHealthCheckTimeoutSeconds
        : ZIO[Any, AwsError, HealthCheckTimeoutSeconds] = AwsError
      .unwrapOptionField("healthCheckTimeoutSeconds", healthCheckTimeoutSeconds)
    def getHealthyThresholdCount
        : ZIO[Any, AwsError, HealthCheckThresholdCount] =
      AwsError.unwrapOptionField("healthyThresholdCount", healthyThresholdCount)
    def getUnhealthyThresholdCount
        : ZIO[Any, AwsError, HealthCheckThresholdCount] = AwsError
      .unwrapOptionField("unhealthyThresholdCount", unhealthyThresholdCount)
    def getHealthCheckPath: ZIO[Any, AwsError, Path] =
      AwsError.unwrapOptionField("healthCheckPath", healthCheckPath)
    def getMatcher: ZIO[
      Any,
      AwsError,
      zio.aws.elasticloadbalancingv2.model.Matcher.ReadOnly
    ] = AwsError.unwrapOptionField("matcher", matcher)
    def getLoadBalancerArns: ZIO[Any, AwsError, List[LoadBalancerArn]] =
      AwsError.unwrapOptionField("loadBalancerArns", loadBalancerArns)
    def getTargetType: ZIO[
      Any,
      AwsError,
      zio.aws.elasticloadbalancingv2.model.TargetTypeEnum
    ] = AwsError.unwrapOptionField("targetType", targetType)
    def getProtocolVersion: ZIO[Any, AwsError, ProtocolVersion] =
      AwsError.unwrapOptionField("protocolVersion", protocolVersion)
    def getIpAddressType: ZIO[
      Any,
      AwsError,
      zio.aws.elasticloadbalancingv2.model.TargetGroupIpAddressTypeEnum
    ] = AwsError.unwrapOptionField("ipAddressType", ipAddressType)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticloadbalancingv2.model.TargetGroup
  ) extends zio.aws.elasticloadbalancingv2.model.TargetGroup.ReadOnly {
    override val targetGroupArn: Option[TargetGroupArn] = scala
      .Option(impl.targetGroupArn())
      .map(value =>
        zio.aws.elasticloadbalancingv2.model.primitives.TargetGroupArn(value)
      )
    override val targetGroupName: Option[TargetGroupName] = scala
      .Option(impl.targetGroupName())
      .map(value =>
        zio.aws.elasticloadbalancingv2.model.primitives.TargetGroupName(value)
      )
    override val protocol
        : Option[zio.aws.elasticloadbalancingv2.model.ProtocolEnum] = scala
      .Option(impl.protocol())
      .map(value =>
        zio.aws.elasticloadbalancingv2.model.ProtocolEnum.wrap(value)
      )
    override val port: Option[Port] = scala
      .Option(impl.port())
      .map(value => zio.aws.elasticloadbalancingv2.model.primitives.Port(value))
    override val vpcId: Option[VpcId] = scala
      .Option(impl.vpcId())
      .map(value =>
        zio.aws.elasticloadbalancingv2.model.primitives.VpcId(value)
      )
    override val healthCheckProtocol
        : Option[zio.aws.elasticloadbalancingv2.model.ProtocolEnum] = scala
      .Option(impl.healthCheckProtocol())
      .map(value =>
        zio.aws.elasticloadbalancingv2.model.ProtocolEnum.wrap(value)
      )
    override val healthCheckPort: Option[HealthCheckPort] = scala
      .Option(impl.healthCheckPort())
      .map(value =>
        zio.aws.elasticloadbalancingv2.model.primitives.HealthCheckPort(value)
      )
    override val healthCheckEnabled: Option[HealthCheckEnabled] = scala
      .Option(impl.healthCheckEnabled())
      .map(value =>
        zio.aws.elasticloadbalancingv2.model.primitives
          .HealthCheckEnabled(value)
      )
    override val healthCheckIntervalSeconds
        : Option[HealthCheckIntervalSeconds] = scala
      .Option(impl.healthCheckIntervalSeconds())
      .map(value =>
        zio.aws.elasticloadbalancingv2.model.primitives
          .HealthCheckIntervalSeconds(value)
      )
    override val healthCheckTimeoutSeconds: Option[HealthCheckTimeoutSeconds] =
      scala
        .Option(impl.healthCheckTimeoutSeconds())
        .map(value =>
          zio.aws.elasticloadbalancingv2.model.primitives
            .HealthCheckTimeoutSeconds(value)
        )
    override val healthyThresholdCount: Option[HealthCheckThresholdCount] =
      scala
        .Option(impl.healthyThresholdCount())
        .map(value =>
          zio.aws.elasticloadbalancingv2.model.primitives
            .HealthCheckThresholdCount(value)
        )
    override val unhealthyThresholdCount: Option[HealthCheckThresholdCount] =
      scala
        .Option(impl.unhealthyThresholdCount())
        .map(value =>
          zio.aws.elasticloadbalancingv2.model.primitives
            .HealthCheckThresholdCount(value)
        )
    override val healthCheckPath: Option[Path] = scala
      .Option(impl.healthCheckPath())
      .map(value => zio.aws.elasticloadbalancingv2.model.primitives.Path(value))
    override val matcher
        : Option[zio.aws.elasticloadbalancingv2.model.Matcher.ReadOnly] = scala
      .Option(impl.matcher())
      .map(value => zio.aws.elasticloadbalancingv2.model.Matcher.wrap(value))
    override val loadBalancerArns: Option[List[LoadBalancerArn]] = scala
      .Option(impl.loadBalancerArns())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.elasticloadbalancingv2.model.primitives.LoadBalancerArn(item)
        }.toList
      )
    override val targetType
        : Option[zio.aws.elasticloadbalancingv2.model.TargetTypeEnum] = scala
      .Option(impl.targetType())
      .map(value =>
        zio.aws.elasticloadbalancingv2.model.TargetTypeEnum.wrap(value)
      )
    override val protocolVersion: Option[ProtocolVersion] = scala
      .Option(impl.protocolVersion())
      .map(value =>
        zio.aws.elasticloadbalancingv2.model.primitives.ProtocolVersion(value)
      )
    override val ipAddressType: Option[
      zio.aws.elasticloadbalancingv2.model.TargetGroupIpAddressTypeEnum
    ] = scala
      .Option(impl.ipAddressType())
      .map(value =>
        zio.aws.elasticloadbalancingv2.model.TargetGroupIpAddressTypeEnum
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticloadbalancingv2.model.TargetGroup
  ): zio.aws.elasticloadbalancingv2.model.TargetGroup.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-elasticloadbalancingv2_2.12-5.17.195.3-sources.jar: zio/aws/elasticloadbalancingv2/model/TargetGroup.scala <==
package zio.aws.elasticloadbalancingv2.model
import zio.aws.elasticloadbalancingv2.model.primitives.{
  VpcId,
  LoadBalancerArn,
  HealthCheckThresholdCount,
  Port,
  HealthCheckTimeoutSeconds,
  ProtocolVersion,
  HealthCheckEnabled,
  HealthCheckIntervalSeconds,
  TargetGroupArn,
  Path,
  TargetGroupName,
  HealthCheckPort
}
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class TargetGroup(
    targetGroupArn: Optional[TargetGroupArn] = Optional.Absent,
    targetGroupName: Optional[TargetGroupName] = Optional.Absent,
    protocol: Optional[zio.aws.elasticloadbalancingv2.model.ProtocolEnum] =
      Optional.Absent,
    port: Optional[Port] = Optional.Absent,
    vpcId: Optional[VpcId] = Optional.Absent,
    healthCheckProtocol: Optional[
      zio.aws.elasticloadbalancingv2.model.ProtocolEnum
    ] = Optional.Absent,
    healthCheckPort: Optional[HealthCheckPort] = Optional.Absent,
    healthCheckEnabled: Optional[HealthCheckEnabled] = Optional.Absent,
    healthCheckIntervalSeconds: Optional[HealthCheckIntervalSeconds] =
      Optional.Absent,
    healthCheckTimeoutSeconds: Optional[HealthCheckTimeoutSeconds] =
      Optional.Absent,
    healthyThresholdCount: Optional[HealthCheckThresholdCount] =
      Optional.Absent,
    unhealthyThresholdCount: Optional[HealthCheckThresholdCount] =
      Optional.Absent,
    healthCheckPath: Optional[Path] = Optional.Absent,
    matcher: Optional[zio.aws.elasticloadbalancingv2.model.Matcher] =
      Optional.Absent,
    loadBalancerArns: Optional[Iterable[LoadBalancerArn]] = Optional.Absent,
    targetType: Optional[zio.aws.elasticloadbalancingv2.model.TargetTypeEnum] =
      Optional.Absent,
    protocolVersion: Optional[ProtocolVersion] = Optional.Absent,
    ipAddressType: Optional[
      zio.aws.elasticloadbalancingv2.model.TargetGroupIpAddressTypeEnum
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.elasticloadbalancingv2.model.TargetGroup = {
    import TargetGroup.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.elasticloadbalancingv2.model.TargetGroup
      .builder()
      .optionallyWith(
        targetGroupArn.map(value =>
          TargetGroupArn.unwrap(value): java.lang.String
        )
      )(_.targetGroupArn)
      .optionallyWith(
        targetGroupName.map(value =>
          TargetGroupName.unwrap(value): java.lang.String
        )
      )(_.targetGroupName)
      .optionallyWith(protocol.map(value => value.unwrap))(_.protocol)
      .optionallyWith(port.map(value => Port.unwrap(value): Integer))(_.port)
      .optionallyWith(
        vpcId.map(value => VpcId.unwrap(value): java.lang.String)
      )(_.vpcId)
      .optionallyWith(healthCheckProtocol.map(value => value.unwrap))(
        _.healthCheckProtocol
      )
      .optionallyWith(
        healthCheckPort.map(value =>
          HealthCheckPort.unwrap(value): java.lang.String
        )
      )(_.healthCheckPort)
      .optionallyWith(
        healthCheckEnabled.map(value =>
          HealthCheckEnabled.unwrap(value): java.lang.Boolean
        )
      )(_.healthCheckEnabled)
      .optionallyWith(
        healthCheckIntervalSeconds.map(value =>
          HealthCheckIntervalSeconds.unwrap(value): Integer
        )
      )(_.healthCheckIntervalSeconds)
      .optionallyWith(
        healthCheckTimeoutSeconds.map(value =>
          HealthCheckTimeoutSeconds.unwrap(value): Integer
        )
      )(_.healthCheckTimeoutSeconds)
      .optionallyWith(
        healthyThresholdCount.map(value =>
          HealthCheckThresholdCount.unwrap(value): Integer
        )
      )(_.healthyThresholdCount)
      .optionallyWith(
        unhealthyThresholdCount.map(value =>
          HealthCheckThresholdCount.unwrap(value): Integer
        )
      )(_.unhealthyThresholdCount)
      .optionallyWith(
        healthCheckPath.map(value => Path.unwrap(value): java.lang.String)
      )(_.healthCheckPath)
      .optionallyWith(matcher.map(value => value.buildAwsValue()))(_.matcher)
      .optionallyWith(
        loadBalancerArns.map(value =>
          value.map { item =>
            LoadBalancerArn.unwrap(item): java.lang.String
          }.asJavaCollection
        )
      )(_.loadBalancerArns)
      .optionallyWith(targetType.map(value => value.unwrap))(_.targetType)
      .optionallyWith(
        protocolVersion.map(value =>
          ProtocolVersion.unwrap(value): java.lang.String
        )
      )(_.protocolVersion)
      .optionallyWith(ipAddressType.map(value => value.unwrap))(_.ipAddressType)
      .build()
  }
  def asReadOnly: zio.aws.elasticloadbalancingv2.model.TargetGroup.ReadOnly =
    zio.aws.elasticloadbalancingv2.model.TargetGroup.wrap(buildAwsValue())
}
object TargetGroup {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.elasticloadbalancingv2.model.TargetGroup
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.elasticloadbalancingv2.model.TargetGroup =
      zio.aws.elasticloadbalancingv2.model.TargetGroup(
        targetGroupArn.map(value => value),
        targetGroupName.map(value => value),
        protocol.map(value => value),
        port.map(value => value),
        vpcId.map(value => value),
        healthCheckProtocol.map(value => value),
        healthCheckPort.map(value => value),
        healthCheckEnabled.map(value => value),
        healthCheckIntervalSeconds.map(value => value),
        healthCheckTimeoutSeconds.map(value => value),
        healthyThresholdCount.map(value => value),
        unhealthyThresholdCount.map(value => value),
        healthCheckPath.map(value => value),
        matcher.map(value => value.asEditable),
        loadBalancerArns.map(value => value),
        targetType.map(value => value),
        protocolVersion.map(value => value),
        ipAddressType.map(value => value)
      )
    def targetGroupArn: Optional[TargetGroupArn]
    def targetGroupName: Optional[TargetGroupName]
    def protocol: Optional[zio.aws.elasticloadbalancingv2.model.ProtocolEnum]
    def port: Optional[Port]
    def vpcId: Optional[VpcId]
    def healthCheckProtocol
        : Optional[zio.aws.elasticloadbalancingv2.model.ProtocolEnum]
    def healthCheckPort: Optional[HealthCheckPort]
    def healthCheckEnabled: Optional[HealthCheckEnabled]
    def healthCheckIntervalSeconds: Optional[HealthCheckIntervalSeconds]
    def healthCheckTimeoutSeconds: Optional[HealthCheckTimeoutSeconds]
    def healthyThresholdCount: Optional[HealthCheckThresholdCount]
    def unhealthyThresholdCount: Optional[HealthCheckThresholdCount]
    def healthCheckPath: Optional[Path]
    def matcher: Optional[zio.aws.elasticloadbalancingv2.model.Matcher.ReadOnly]
    def loadBalancerArns: Optional[List[LoadBalancerArn]]
    def targetType
        : Optional[zio.aws.elasticloadbalancingv2.model.TargetTypeEnum]
    def protocolVersion: Optional[ProtocolVersion]
    def ipAddressType: Optional[
      zio.aws.elasticloadbalancingv2.model.TargetGroupIpAddressTypeEnum
    ]
    def getTargetGroupArn: ZIO[Any, AwsError, TargetGroupArn] =
      AwsError.unwrapOptionField("targetGroupArn", targetGroupArn)
    def getTargetGroupName: ZIO[Any, AwsError, TargetGroupName] =
      AwsError.unwrapOptionField("targetGroupName", targetGroupName)
    def getProtocol: ZIO[
      Any,
      AwsError,
      zio.aws.elasticloadbalancingv2.model.ProtocolEnum
    ] = AwsError.unwrapOptionField("protocol", protocol)
    def getPort: ZIO[Any, AwsError, Port] =
      AwsError.unwrapOptionField("port", port)
    def getVpcId: ZIO[Any, AwsError, VpcId] =
      AwsError.unwrapOptionField("vpcId", vpcId)
    def getHealthCheckProtocol: ZIO[
      Any,
      AwsError,
      zio.aws.elasticloadbalancingv2.model.ProtocolEnum
    ] = AwsError.unwrapOptionField("healthCheckProtocol", healthCheckProtocol)
    def getHealthCheckPort: ZIO[Any, AwsError, HealthCheckPort] =
      AwsError.unwrapOptionField("healthCheckPort", healthCheckPort)
    def getHealthCheckEnabled: ZIO[Any, AwsError, HealthCheckEnabled] =
      AwsError.unwrapOptionField("healthCheckEnabled", healthCheckEnabled)
    def getHealthCheckIntervalSeconds
        : ZIO[Any, AwsError, HealthCheckIntervalSeconds] =
      AwsError.unwrapOptionField(
        "healthCheckIntervalSeconds",
        healthCheckIntervalSeconds
      )
    def getHealthCheckTimeoutSeconds
        : ZIO[Any, AwsError, HealthCheckTimeoutSeconds] = AwsError
      .unwrapOptionField("healthCheckTimeoutSeconds", healthCheckTimeoutSeconds)
    def getHealthyThresholdCount
        : ZIO[Any, AwsError, HealthCheckThresholdCount] =
      AwsError.unwrapOptionField("healthyThresholdCount", healthyThresholdCount)
    def getUnhealthyThresholdCount
        : ZIO[Any, AwsError, HealthCheckThresholdCount] = AwsError
      .unwrapOptionField("unhealthyThresholdCount", unhealthyThresholdCount)
    def getHealthCheckPath: ZIO[Any, AwsError, Path] =
      AwsError.unwrapOptionField("healthCheckPath", healthCheckPath)
    def getMatcher: ZIO[
      Any,
      AwsError,
      zio.aws.elasticloadbalancingv2.model.Matcher.ReadOnly
    ] = AwsError.unwrapOptionField("matcher", matcher)
    def getLoadBalancerArns: ZIO[Any, AwsError, List[LoadBalancerArn]] =
      AwsError.unwrapOptionField("loadBalancerArns", loadBalancerArns)
    def getTargetType: ZIO[
      Any,
      AwsError,
      zio.aws.elasticloadbalancingv2.model.TargetTypeEnum
    ] = AwsError.unwrapOptionField("targetType", targetType)
    def getProtocolVersion: ZIO[Any, AwsError, ProtocolVersion] =
      AwsError.unwrapOptionField("protocolVersion", protocolVersion)
    def getIpAddressType: ZIO[
      Any,
      AwsError,
      zio.aws.elasticloadbalancingv2.model.TargetGroupIpAddressTypeEnum
    ] = AwsError.unwrapOptionField("ipAddressType", ipAddressType)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.elasticloadbalancingv2.model.TargetGroup
  ) extends zio.aws.elasticloadbalancingv2.model.TargetGroup.ReadOnly {
    override val targetGroupArn: Optional[TargetGroupArn] =
      zio.aws.core.internal
        .optionalFromNullable(impl.targetGroupArn())
        .map(value =>
          zio.aws.elasticloadbalancingv2.model.primitives.TargetGroupArn(value)
        )
    override val targetGroupName: Optional[TargetGroupName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.targetGroupName())
        .map(value =>
          zio.aws.elasticloadbalancingv2.model.primitives.TargetGroupName(value)
        )
    override val protocol
        : Optional[zio.aws.elasticloadbalancingv2.model.ProtocolEnum] =
      zio.aws.core.internal
        .optionalFromNullable(impl.protocol())
        .map(value =>
          zio.aws.elasticloadbalancingv2.model.ProtocolEnum.wrap(value)
        )
    override val port: Optional[Port] = zio.aws.core.internal
      .optionalFromNullable(impl.port())
      .map(value => zio.aws.elasticloadbalancingv2.model.primitives.Port(value))
    override val vpcId: Optional[VpcId] = zio.aws.core.internal
      .optionalFromNullable(impl.vpcId())
      .map(value =>
        zio.aws.elasticloadbalancingv2.model.primitives.VpcId(value)
      )
    override val healthCheckProtocol
        : Optional[zio.aws.elasticloadbalancingv2.model.ProtocolEnum] =
      zio.aws.core.internal
        .optionalFromNullable(impl.healthCheckProtocol())
        .map(value =>
          zio.aws.elasticloadbalancingv2.model.ProtocolEnum.wrap(value)
        )
    override val healthCheckPort: Optional[HealthCheckPort] =
      zio.aws.core.internal
        .optionalFromNullable(impl.healthCheckPort())
        .map(value =>
          zio.aws.elasticloadbalancingv2.model.primitives.HealthCheckPort(value)
        )
    override val healthCheckEnabled: Optional[HealthCheckEnabled] =
      zio.aws.core.internal
        .optionalFromNullable(impl.healthCheckEnabled())
        .map(value =>
          zio.aws.elasticloadbalancingv2.model.primitives
            .HealthCheckEnabled(value)
        )
    override val healthCheckIntervalSeconds
        : Optional[HealthCheckIntervalSeconds] = zio.aws.core.internal
      .optionalFromNullable(impl.healthCheckIntervalSeconds())
      .map(value =>
        zio.aws.elasticloadbalancingv2.model.primitives
          .HealthCheckIntervalSeconds(value)
      )
    override val healthCheckTimeoutSeconds
        : Optional[HealthCheckTimeoutSeconds] = zio.aws.core.internal
      .optionalFromNullable(impl.healthCheckTimeoutSeconds())
      .map(value =>
        zio.aws.elasticloadbalancingv2.model.primitives
          .HealthCheckTimeoutSeconds(value)
      )
    override val healthyThresholdCount: Optional[HealthCheckThresholdCount] =
      zio.aws.core.internal
        .optionalFromNullable(impl.healthyThresholdCount())
        .map(value =>
          zio.aws.elasticloadbalancingv2.model.primitives
            .HealthCheckThresholdCount(value)
        )
    override val unhealthyThresholdCount: Optional[HealthCheckThresholdCount] =
      zio.aws.core.internal
        .optionalFromNullable(impl.unhealthyThresholdCount())
        .map(value =>
          zio.aws.elasticloadbalancingv2.model.primitives
            .HealthCheckThresholdCount(value)
        )
    override val healthCheckPath: Optional[Path] = zio.aws.core.internal
      .optionalFromNullable(impl.healthCheckPath())
      .map(value => zio.aws.elasticloadbalancingv2.model.primitives.Path(value))
    override val matcher
        : Optional[zio.aws.elasticloadbalancingv2.model.Matcher.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.matcher())
        .map(value => zio.aws.elasticloadbalancingv2.model.Matcher.wrap(value))
    override val loadBalancerArns: Optional[List[LoadBalancerArn]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.loadBalancerArns())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.elasticloadbalancingv2.model.primitives
              .LoadBalancerArn(item)
          }.toList
        )
    override val targetType
        : Optional[zio.aws.elasticloadbalancingv2.model.TargetTypeEnum] =
      zio.aws.core.internal
        .optionalFromNullable(impl.targetType())
        .map(value =>
          zio.aws.elasticloadbalancingv2.model.TargetTypeEnum.wrap(value)
        )
    override val protocolVersion: Optional[ProtocolVersion] =
      zio.aws.core.internal
        .optionalFromNullable(impl.protocolVersion())
        .map(value =>
          zio.aws.elasticloadbalancingv2.model.primitives.ProtocolVersion(value)
        )
    override val ipAddressType: Optional[
      zio.aws.elasticloadbalancingv2.model.TargetGroupIpAddressTypeEnum
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.ipAddressType())
      .map(value =>
        zio.aws.elasticloadbalancingv2.model.TargetGroupIpAddressTypeEnum
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.elasticloadbalancingv2.model.TargetGroup
  ): zio.aws.elasticloadbalancingv2.model.TargetGroup.ReadOnly = new Wrapper(
    impl
  )
}
